@@ -11,8 +11,6 @@ use polars::{
     prelude::{DataType, PolarsError, Series},
 };
 
-use super::utils::convert_columns;
-
 enum Operation {
     Mean,
     Sum,
@@ -84,23 +82,23 @@ impl WholeStreamCommand for DataFrame {
     }
 
     fn usage(&self) -> &str {
-        "Performs an aggregation operation on a dataframe or groupby object"
+        "[DataFrame, GroupBy, Series] Performs an aggregation operation on a dataframe, groupby or series object"
     }
 
     fn signature(&self) -> Signature {
         Signature::build("dataframe aggregate")
             .required("operation", SyntaxShape::String, "aggregate operation")
-            .optional(
-                "selection",
-                SyntaxShape::Table,
-                "columns to perform aggregation",
-            )
             .named(
                 "quantile",
                 SyntaxShape::Number,
                 "quantile value for quantile operation",
                 Some('q'),
             )
+            .switch(
+                "explicit",
+                "returns explicit names for groupby aggregations",
+                Some('e'),
+            )
     }
 
     fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
@@ -112,7 +110,7 @@ impl WholeStreamCommand for DataFrame {
             Example {
                 description: "Aggregate sum by grouping by column a and summing on col b",
                 example:
-                    "[[a b]; [one 1] [one 2]] | dataframe to-df | dataframe group-by [a] | dataframe aggregate sum",
+                    "[[a b]; [one 1] [one 2]] | dataframe to-df | dataframe group-by a | dataframe aggregate sum",
                 result: None,
             },
             Example {
@@ -136,16 +134,6 @@ fn command(mut args: CommandArgs) -> Result<OutputStream, ShellError> {
     let operation: Tagged<String> = args.req(0)?;
     let op = Operation::from_tagged(&operation, quantile)?;
 
-    // Extracting the selection columns of the columns to perform the aggregation
-    let agg_cols: Option<Vec<Value>> = args.opt(1)?;
-    let (selection, agg_span) = match agg_cols {
-        Some(cols) => {
-            let (agg_string, agg_span) = convert_columns(&cols, &tag)?;
-            (Some(agg_string), agg_span)
-        }
-        None => (None, Span::unknown()),
-    };
-
     let value = args.input.next().ok_or_else(|| {
         ShellError::labeled_error("Empty stream", "No value found in the stream", &tag)
     })?;
@@ -154,28 +142,20 @@ fn command(mut args: CommandArgs) -> Result<OutputStream, ShellError> {
         UntaggedValue::DataFrame(PolarsData::GroupBy(nu_groupby)) => {
             let groupby = nu_groupby.to_groupby()?;
 
-            let groupby = match &selection {
-                Some(cols) => groupby.select(cols),
-                None => groupby,
-            };
-
-            let res = perform_groupby_aggregation(groupby, op, &operation.tag, &agg_span)?;
+            let res = perform_groupby_aggregation(
+                groupby,
+                op,
+                &operation.tag,
+                &tag.span,
+                args.has_flag("explicit"),
+            )?;
 
             Ok(OutputStream::one(NuDataFrame::dataframe_to_value(res, tag)))
         }
         UntaggedValue::DataFrame(PolarsData::EagerDataFrame(df)) => {
             let df = df.as_ref();
 
-            let res = match &selection {
-                Some(cols) => {
-                    let df = df
-                        .select(cols)
-                        .map_err(|e| parse_polars_error::<&str>(&e, &agg_span, None))?;
-
-                    perform_dataframe_aggregation(&df, op, &operation.tag)
-                }
-                None => perform_dataframe_aggregation(&df, op, &operation.tag),
-            }?;
+            let res = perform_dataframe_aggregation(&df, op, &operation.tag)?;
 
             Ok(OutputStream::one(NuDataFrame::dataframe_to_value(res, tag)))
         }
@@ -185,8 +165,8 @@ fn command(mut args: CommandArgs) -> Result<OutputStream, ShellError> {
             Ok(OutputStream::one(value))
         }
         _ => Err(ShellError::labeled_error(
-            "No groupby or dataframe",
-            "no groupby or found in input stream",
+            "No groupby, dataframe or series in stream",
+            "no groupby, dataframe or series found in input stream",
             &value.tag.span,
         )),
     }
@@ -197,8 +177,9 @@ fn perform_groupby_aggregation(
     operation: Operation,
     operation_tag: &Tag,
     agg_span: &Span,
+    explicit: bool,
 ) -> Result<polars::prelude::DataFrame, ShellError> {
-    match operation {
+    let mut res = match operation {
         Operation::Mean => groupby.mean(),
         Operation::Sum => groupby.sum(),
         Operation::Min => groupby.min(),
@@ -219,7 +200,42 @@ fn perform_groupby_aggregation(
         };
 
         parse_polars_error::<&str>(&e, span, None)
-    })
+    })?;
+
+    if !explicit {
+        let col_names = res
+            .get_column_names()
+            .iter()
+            .map(|name| name.to_string())
+            .collect::<Vec<String>>();
+
+        for col in col_names {
+            let from = match operation {
+                Operation::Mean => "_mean",
+                Operation::Sum => "_sum",
+                Operation::Min => "_min",
+                Operation::Max => "_max",
+                Operation::First => "_first",
+                Operation::Last => "_last",
+                Operation::Nunique => "_n_unique",
+                Operation::Quantile(_) => "_quantile",
+                Operation::Median => "_median",
+                Operation::Var => "_agg_var",
+                Operation::Std => "_agg_std",
+                Operation::Count => "_count",
+            };
+
+            let new_col = match col.find(from) {
+                Some(index) => &col[..index],
+                None => &col[..],
+            };
+
+            res.rename(col.as_str(), new_col)
+                .expect("Column is always there. Looping with known names");
+        }
+    }
+
+    Ok(res)
 }
 
 fn perform_dataframe_aggregation(
@@ -266,7 +282,7 @@ fn perform_series_aggregation(
             };
 
             let mut data = TaggedDictBuilder::new(operation_tag.clone());
-            data.insert_value("mean", value);
+            data.insert_value(series.name(), value);
 
             Ok(data.into_value())
         }
@@ -282,7 +298,7 @@ fn perform_series_aggregation(
             };
 
             let mut data = TaggedDictBuilder::new(operation_tag.clone());
-            data.insert_value("median", value);
+            data.insert_value(series.name(), value);
 
             Ok(data.into_value())
         }
@@ -319,7 +335,7 @@ fn perform_series_aggregation(
             };
 
             let mut data = TaggedDictBuilder::new(operation_tag.clone());
-            data.insert_value("sum", value);
+            data.insert_value(series.name(), value);
 
             Ok(data.into_value())
         }
@@ -356,7 +372,7 @@ fn perform_series_aggregation(
             };
 
             let mut data = TaggedDictBuilder::new(operation_tag.clone());
-            data.insert_value("max", value);
+            data.insert_value(series.name(), value);
 
             Ok(data.into_value())
         }
@@ -393,7 +409,7 @@ fn perform_series_aggregation(
             };
 
             let mut data = TaggedDictBuilder::new(operation_tag.clone());
-            data.insert_value("min", value);
+            data.insert_value(series.name(), value);
 
             Ok(data.into_value())
         }
