@@ -12,15 +12,11 @@ impl WholeStreamCommand for DataFrame {
     }
 
     fn usage(&self) -> &str {
-        "Creates dataframe with the selected columns"
+        "[DataFrame] Creates dataframe with the selected columns"
     }
 
     fn signature(&self) -> Signature {
-        Signature::build("dataframe get").required(
-            "columns",
-            SyntaxShape::Table,
-            "column names to sort dataframe",
-        )
+        Signature::build("dataframe get").rest(SyntaxShape::Any, "column names to sort dataframe")
     }
 
     fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
@@ -30,7 +26,7 @@ impl WholeStreamCommand for DataFrame {
     fn examples(&self) -> Vec<Example> {
         vec![Example {
             description: "Creates dataframe with selected columns",
-            example: "[[a b]; [1 2] [3 4]] | dataframe to-df | dataframe get [a]",
+            example: "[[a b]; [1 2] [3 4]] | dataframe to-df | dataframe get a",
             result: None,
         }]
     }
@@ -38,7 +34,7 @@ impl WholeStreamCommand for DataFrame {
 
 fn command(mut args: CommandArgs) -> Result<OutputStream, ShellError> {
     let tag = args.call_info.name_tag.clone();
-    let columns: Vec<Value> = args.req(0)?;
+    let columns: Vec<Value> = args.rest(0)?;
 
     let (col_string, col_span) = convert_columns(&columns, &tag)?;
 
