@@ -12,8 +12,10 @@ pub mod is_null;
 pub mod is_unique;
 pub mod n_null;
 pub mod n_unique;
+pub mod not;
 pub mod rename;
 pub mod set;
+pub mod set_with_idx;
 pub mod shift;
 pub mod unique;
 pub mod value_counts;
@@ -32,8 +34,10 @@ pub use is_null::DataFrame as DataFrameIsNull;
 pub use is_unique::DataFrame as DataFrameIsUnique;
 pub use n_null::DataFrame as DataFrameNNull;
 pub use n_unique::DataFrame as DataFrameNUnique;
+pub use not::DataFrame as DataFrameNot;
 pub use rename::DataFrame as DataFrameSeriesRename;
 pub use set::DataFrame as DataFrameSet;
+pub use set_with_idx::DataFrame as DataFrameSetWithIdx;
 pub use shift::DataFrame as DataFrameShift;
 pub use unique::DataFrame as DataFrameUnique;
 pub use value_counts::DataFrame as DataFrameValueCounts;
